# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKPDEDeformableRegistrationPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkPDEDeformableRegistrationFilterPython
else:
    import _itkPDEDeformableRegistrationFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkSizePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.ITKCommonBasePython
import itk.itkImageRegionPython
import itk.itkDenseFiniteDifferenceImageFilterPython
import itk.itkFiniteDifferenceImageFilterPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterBPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageSourcePython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourceCommonPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterAPython
import itk.itkFiniteDifferenceFunctionPython

def itkPDEDeformableRegistrationFilterIF2IF2IVF22_New():
    return itkPDEDeformableRegistrationFilterIF2IF2IVF22.New()

class itkPDEDeformableRegistrationFilterIF2IF2IVF22(itk.itkDenseFiniteDifferenceImageFilterPython.itkDenseFiniteDifferenceImageFilterIVF22IVF22):
    r"""Proxy of C++ itkPDEDeformableRegistrationFilterIF2IF2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPDEDeformableRegistrationFilterIF2IF2IVF22_Pointer"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPDEDeformableRegistrationFilterIF2IF2IVF22_Pointer"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_Clone(self)

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF2 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF2"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF2 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF2"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_GetMovingImage(self)

    def SetInitialDisplacementField(self, _arg):
        r"""
        SetInitialDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: itkImageVF22 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SetInitialDisplacementField(self, _arg)

    def GetInitialDisplacementField(self):
        r"""GetInitialDisplacementField(self) -> itkImageVF22"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_GetInitialDisplacementField(self)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF22"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_GetDisplacementField(self)

    def SetSmoothDisplacementField(self, _arg):
        r"""
        SetSmoothDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SetSmoothDisplacementField(self, _arg)

    def GetSmoothDisplacementField(self):
        r"""GetSmoothDisplacementField(self) -> bool"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_GetSmoothDisplacementField(self)

    def SmoothDisplacementFieldOn(self):
        r"""SmoothDisplacementFieldOn(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SmoothDisplacementFieldOn(self)

    def SmoothDisplacementFieldOff(self):
        r"""SmoothDisplacementFieldOff(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SmoothDisplacementFieldOff(self)

    def SetStandardDeviations(self, *args):
        r"""
        SetStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        SetStandardDeviations(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SetStandardDeviations(self, *args)

    def GetStandardDeviations(self):
        r"""GetStandardDeviations(self) -> itkFixedArrayD2"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_GetStandardDeviations(self)

    def SetSmoothUpdateField(self, _arg):
        r"""
        SetSmoothUpdateField(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SetSmoothUpdateField(self, _arg)

    def GetSmoothUpdateField(self):
        r"""GetSmoothUpdateField(self) -> bool"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_GetSmoothUpdateField(self)

    def SmoothUpdateFieldOn(self):
        r"""SmoothUpdateFieldOn(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SmoothUpdateFieldOn(self)

    def SmoothUpdateFieldOff(self):
        r"""SmoothUpdateFieldOff(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SmoothUpdateFieldOff(self)

    def SetUpdateFieldStandardDeviations(self, *args):
        r"""
        SetUpdateFieldStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        SetUpdateFieldStandardDeviations(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SetUpdateFieldStandardDeviations(self, *args)

    def GetUpdateFieldStandardDeviations(self):
        r"""GetUpdateFieldStandardDeviations(self) -> itkFixedArrayD2"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_GetUpdateFieldStandardDeviations(self)

    def StopRegistration(self):
        r"""StopRegistration(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_StopRegistration(self)

    def SetMaximumError(self, _arg):
        r"""
        SetMaximumError(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SetMaximumError(self, _arg)

    def GetMaximumError(self):
        r"""GetMaximumError(self) -> double"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_GetMaximumError(self)

    def SetMaximumKernelWidth(self, _arg):
        r"""
        SetMaximumKernelWidth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_SetMaximumKernelWidth(self, _arg)

    def GetMaximumKernelWidth(self):
        r"""GetMaximumKernelWidth(self) -> unsigned int"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_GetMaximumKernelWidth(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFilterPython.delete_itkPDEDeformableRegistrationFilterIF2IF2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFilterIF2IF2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPDEDeformableRegistrationFilterIF2IF2IVF22

        Create a new object of the class itkPDEDeformableRegistrationFilterIF2IF2IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPDEDeformableRegistrationFilterIF2IF2IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPDEDeformableRegistrationFilterIF2IF2IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPDEDeformableRegistrationFilterIF2IF2IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPDEDeformableRegistrationFilterIF2IF2IVF22 in _itkPDEDeformableRegistrationFilterPython:
_itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22_swigregister(itkPDEDeformableRegistrationFilterIF2IF2IVF22)

def itkPDEDeformableRegistrationFilterIF3IF3IVF33_New():
    return itkPDEDeformableRegistrationFilterIF3IF3IVF33.New()

class itkPDEDeformableRegistrationFilterIF3IF3IVF33(itk.itkDenseFiniteDifferenceImageFilterPython.itkDenseFiniteDifferenceImageFilterIVF33IVF33):
    r"""Proxy of C++ itkPDEDeformableRegistrationFilterIF3IF3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPDEDeformableRegistrationFilterIF3IF3IVF33_Pointer"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPDEDeformableRegistrationFilterIF3IF3IVF33_Pointer"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_Clone(self)

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF3 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF3"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF3 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF3"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_GetMovingImage(self)

    def SetInitialDisplacementField(self, _arg):
        r"""
        SetInitialDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: itkImageVF33 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SetInitialDisplacementField(self, _arg)

    def GetInitialDisplacementField(self):
        r"""GetInitialDisplacementField(self) -> itkImageVF33"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_GetInitialDisplacementField(self)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF33"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_GetDisplacementField(self)

    def SetSmoothDisplacementField(self, _arg):
        r"""
        SetSmoothDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SetSmoothDisplacementField(self, _arg)

    def GetSmoothDisplacementField(self):
        r"""GetSmoothDisplacementField(self) -> bool"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_GetSmoothDisplacementField(self)

    def SmoothDisplacementFieldOn(self):
        r"""SmoothDisplacementFieldOn(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SmoothDisplacementFieldOn(self)

    def SmoothDisplacementFieldOff(self):
        r"""SmoothDisplacementFieldOff(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SmoothDisplacementFieldOff(self)

    def SetStandardDeviations(self, *args):
        r"""
        SetStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        SetStandardDeviations(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SetStandardDeviations(self, *args)

    def GetStandardDeviations(self):
        r"""GetStandardDeviations(self) -> itkFixedArrayD3"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_GetStandardDeviations(self)

    def SetSmoothUpdateField(self, _arg):
        r"""
        SetSmoothUpdateField(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SetSmoothUpdateField(self, _arg)

    def GetSmoothUpdateField(self):
        r"""GetSmoothUpdateField(self) -> bool"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_GetSmoothUpdateField(self)

    def SmoothUpdateFieldOn(self):
        r"""SmoothUpdateFieldOn(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SmoothUpdateFieldOn(self)

    def SmoothUpdateFieldOff(self):
        r"""SmoothUpdateFieldOff(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SmoothUpdateFieldOff(self)

    def SetUpdateFieldStandardDeviations(self, *args):
        r"""
        SetUpdateFieldStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        SetUpdateFieldStandardDeviations(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SetUpdateFieldStandardDeviations(self, *args)

    def GetUpdateFieldStandardDeviations(self):
        r"""GetUpdateFieldStandardDeviations(self) -> itkFixedArrayD3"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_GetUpdateFieldStandardDeviations(self)

    def StopRegistration(self):
        r"""StopRegistration(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_StopRegistration(self)

    def SetMaximumError(self, _arg):
        r"""
        SetMaximumError(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SetMaximumError(self, _arg)

    def GetMaximumError(self):
        r"""GetMaximumError(self) -> double"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_GetMaximumError(self)

    def SetMaximumKernelWidth(self, _arg):
        r"""
        SetMaximumKernelWidth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_SetMaximumKernelWidth(self, _arg)

    def GetMaximumKernelWidth(self):
        r"""GetMaximumKernelWidth(self) -> unsigned int"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_GetMaximumKernelWidth(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFilterPython.delete_itkPDEDeformableRegistrationFilterIF3IF3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFilterIF3IF3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPDEDeformableRegistrationFilterIF3IF3IVF33

        Create a new object of the class itkPDEDeformableRegistrationFilterIF3IF3IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPDEDeformableRegistrationFilterIF3IF3IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPDEDeformableRegistrationFilterIF3IF3IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPDEDeformableRegistrationFilterIF3IF3IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPDEDeformableRegistrationFilterIF3IF3IVF33 in _itkPDEDeformableRegistrationFilterPython:
_itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33_swigregister(itkPDEDeformableRegistrationFilterIF3IF3IVF33)

def itkPDEDeformableRegistrationFilterISS2ISS2IVF22_New():
    return itkPDEDeformableRegistrationFilterISS2ISS2IVF22.New()

class itkPDEDeformableRegistrationFilterISS2ISS2IVF22(itk.itkDenseFiniteDifferenceImageFilterPython.itkDenseFiniteDifferenceImageFilterIVF22IVF22):
    r"""Proxy of C++ itkPDEDeformableRegistrationFilterISS2ISS2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPDEDeformableRegistrationFilterISS2ISS2IVF22_Pointer"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPDEDeformableRegistrationFilterISS2ISS2IVF22_Pointer"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_Clone(self)

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS2"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS2"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_GetMovingImage(self)

    def SetInitialDisplacementField(self, _arg):
        r"""
        SetInitialDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: itkImageVF22 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SetInitialDisplacementField(self, _arg)

    def GetInitialDisplacementField(self):
        r"""GetInitialDisplacementField(self) -> itkImageVF22"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_GetInitialDisplacementField(self)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF22"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_GetDisplacementField(self)

    def SetSmoothDisplacementField(self, _arg):
        r"""
        SetSmoothDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SetSmoothDisplacementField(self, _arg)

    def GetSmoothDisplacementField(self):
        r"""GetSmoothDisplacementField(self) -> bool"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_GetSmoothDisplacementField(self)

    def SmoothDisplacementFieldOn(self):
        r"""SmoothDisplacementFieldOn(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SmoothDisplacementFieldOn(self)

    def SmoothDisplacementFieldOff(self):
        r"""SmoothDisplacementFieldOff(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SmoothDisplacementFieldOff(self)

    def SetStandardDeviations(self, *args):
        r"""
        SetStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        SetStandardDeviations(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SetStandardDeviations(self, *args)

    def GetStandardDeviations(self):
        r"""GetStandardDeviations(self) -> itkFixedArrayD2"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_GetStandardDeviations(self)

    def SetSmoothUpdateField(self, _arg):
        r"""
        SetSmoothUpdateField(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SetSmoothUpdateField(self, _arg)

    def GetSmoothUpdateField(self):
        r"""GetSmoothUpdateField(self) -> bool"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_GetSmoothUpdateField(self)

    def SmoothUpdateFieldOn(self):
        r"""SmoothUpdateFieldOn(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SmoothUpdateFieldOn(self)

    def SmoothUpdateFieldOff(self):
        r"""SmoothUpdateFieldOff(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SmoothUpdateFieldOff(self)

    def SetUpdateFieldStandardDeviations(self, *args):
        r"""
        SetUpdateFieldStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        SetUpdateFieldStandardDeviations(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SetUpdateFieldStandardDeviations(self, *args)

    def GetUpdateFieldStandardDeviations(self):
        r"""GetUpdateFieldStandardDeviations(self) -> itkFixedArrayD2"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_GetUpdateFieldStandardDeviations(self)

    def StopRegistration(self):
        r"""StopRegistration(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_StopRegistration(self)

    def SetMaximumError(self, _arg):
        r"""
        SetMaximumError(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SetMaximumError(self, _arg)

    def GetMaximumError(self):
        r"""GetMaximumError(self) -> double"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_GetMaximumError(self)

    def SetMaximumKernelWidth(self, _arg):
        r"""
        SetMaximumKernelWidth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_SetMaximumKernelWidth(self, _arg)

    def GetMaximumKernelWidth(self):
        r"""GetMaximumKernelWidth(self) -> unsigned int"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_GetMaximumKernelWidth(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFilterPython.delete_itkPDEDeformableRegistrationFilterISS2ISS2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFilterISS2ISS2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPDEDeformableRegistrationFilterISS2ISS2IVF22

        Create a new object of the class itkPDEDeformableRegistrationFilterISS2ISS2IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPDEDeformableRegistrationFilterISS2ISS2IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPDEDeformableRegistrationFilterISS2ISS2IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPDEDeformableRegistrationFilterISS2ISS2IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPDEDeformableRegistrationFilterISS2ISS2IVF22 in _itkPDEDeformableRegistrationFilterPython:
_itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22_swigregister(itkPDEDeformableRegistrationFilterISS2ISS2IVF22)

def itkPDEDeformableRegistrationFilterISS3ISS3IVF33_New():
    return itkPDEDeformableRegistrationFilterISS3ISS3IVF33.New()

class itkPDEDeformableRegistrationFilterISS3ISS3IVF33(itk.itkDenseFiniteDifferenceImageFilterPython.itkDenseFiniteDifferenceImageFilterIVF33IVF33):
    r"""Proxy of C++ itkPDEDeformableRegistrationFilterISS3ISS3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPDEDeformableRegistrationFilterISS3ISS3IVF33_Pointer"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPDEDeformableRegistrationFilterISS3ISS3IVF33_Pointer"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_Clone(self)

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS3"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS3"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_GetMovingImage(self)

    def SetInitialDisplacementField(self, _arg):
        r"""
        SetInitialDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: itkImageVF33 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SetInitialDisplacementField(self, _arg)

    def GetInitialDisplacementField(self):
        r"""GetInitialDisplacementField(self) -> itkImageVF33"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_GetInitialDisplacementField(self)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF33"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_GetDisplacementField(self)

    def SetSmoothDisplacementField(self, _arg):
        r"""
        SetSmoothDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SetSmoothDisplacementField(self, _arg)

    def GetSmoothDisplacementField(self):
        r"""GetSmoothDisplacementField(self) -> bool"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_GetSmoothDisplacementField(self)

    def SmoothDisplacementFieldOn(self):
        r"""SmoothDisplacementFieldOn(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SmoothDisplacementFieldOn(self)

    def SmoothDisplacementFieldOff(self):
        r"""SmoothDisplacementFieldOff(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SmoothDisplacementFieldOff(self)

    def SetStandardDeviations(self, *args):
        r"""
        SetStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        SetStandardDeviations(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SetStandardDeviations(self, *args)

    def GetStandardDeviations(self):
        r"""GetStandardDeviations(self) -> itkFixedArrayD3"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_GetStandardDeviations(self)

    def SetSmoothUpdateField(self, _arg):
        r"""
        SetSmoothUpdateField(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SetSmoothUpdateField(self, _arg)

    def GetSmoothUpdateField(self):
        r"""GetSmoothUpdateField(self) -> bool"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_GetSmoothUpdateField(self)

    def SmoothUpdateFieldOn(self):
        r"""SmoothUpdateFieldOn(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SmoothUpdateFieldOn(self)

    def SmoothUpdateFieldOff(self):
        r"""SmoothUpdateFieldOff(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SmoothUpdateFieldOff(self)

    def SetUpdateFieldStandardDeviations(self, *args):
        r"""
        SetUpdateFieldStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        SetUpdateFieldStandardDeviations(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SetUpdateFieldStandardDeviations(self, *args)

    def GetUpdateFieldStandardDeviations(self):
        r"""GetUpdateFieldStandardDeviations(self) -> itkFixedArrayD3"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_GetUpdateFieldStandardDeviations(self)

    def StopRegistration(self):
        r"""StopRegistration(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_StopRegistration(self)

    def SetMaximumError(self, _arg):
        r"""
        SetMaximumError(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SetMaximumError(self, _arg)

    def GetMaximumError(self):
        r"""GetMaximumError(self) -> double"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_GetMaximumError(self)

    def SetMaximumKernelWidth(self, _arg):
        r"""
        SetMaximumKernelWidth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_SetMaximumKernelWidth(self, _arg)

    def GetMaximumKernelWidth(self):
        r"""GetMaximumKernelWidth(self) -> unsigned int"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_GetMaximumKernelWidth(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFilterPython.delete_itkPDEDeformableRegistrationFilterISS3ISS3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFilterISS3ISS3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPDEDeformableRegistrationFilterISS3ISS3IVF33

        Create a new object of the class itkPDEDeformableRegistrationFilterISS3ISS3IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPDEDeformableRegistrationFilterISS3ISS3IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPDEDeformableRegistrationFilterISS3ISS3IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPDEDeformableRegistrationFilterISS3ISS3IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPDEDeformableRegistrationFilterISS3ISS3IVF33 in _itkPDEDeformableRegistrationFilterPython:
_itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33_swigregister(itkPDEDeformableRegistrationFilterISS3ISS3IVF33)

def itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_New():
    return itkPDEDeformableRegistrationFilterIUC2IUC2IVF22.New()

class itkPDEDeformableRegistrationFilterIUC2IUC2IVF22(itk.itkDenseFiniteDifferenceImageFilterPython.itkDenseFiniteDifferenceImageFilterIVF22IVF22):
    r"""Proxy of C++ itkPDEDeformableRegistrationFilterIUC2IUC2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_Pointer"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_Pointer"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_Clone(self)

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC2"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC2"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_GetMovingImage(self)

    def SetInitialDisplacementField(self, _arg):
        r"""
        SetInitialDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: itkImageVF22 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SetInitialDisplacementField(self, _arg)

    def GetInitialDisplacementField(self):
        r"""GetInitialDisplacementField(self) -> itkImageVF22"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_GetInitialDisplacementField(self)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF22"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_GetDisplacementField(self)

    def SetSmoothDisplacementField(self, _arg):
        r"""
        SetSmoothDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SetSmoothDisplacementField(self, _arg)

    def GetSmoothDisplacementField(self):
        r"""GetSmoothDisplacementField(self) -> bool"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_GetSmoothDisplacementField(self)

    def SmoothDisplacementFieldOn(self):
        r"""SmoothDisplacementFieldOn(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SmoothDisplacementFieldOn(self)

    def SmoothDisplacementFieldOff(self):
        r"""SmoothDisplacementFieldOff(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SmoothDisplacementFieldOff(self)

    def SetStandardDeviations(self, *args):
        r"""
        SetStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        SetStandardDeviations(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SetStandardDeviations(self, *args)

    def GetStandardDeviations(self):
        r"""GetStandardDeviations(self) -> itkFixedArrayD2"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_GetStandardDeviations(self)

    def SetSmoothUpdateField(self, _arg):
        r"""
        SetSmoothUpdateField(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SetSmoothUpdateField(self, _arg)

    def GetSmoothUpdateField(self):
        r"""GetSmoothUpdateField(self) -> bool"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_GetSmoothUpdateField(self)

    def SmoothUpdateFieldOn(self):
        r"""SmoothUpdateFieldOn(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SmoothUpdateFieldOn(self)

    def SmoothUpdateFieldOff(self):
        r"""SmoothUpdateFieldOff(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SmoothUpdateFieldOff(self)

    def SetUpdateFieldStandardDeviations(self, *args):
        r"""
        SetUpdateFieldStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        SetUpdateFieldStandardDeviations(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SetUpdateFieldStandardDeviations(self, *args)

    def GetUpdateFieldStandardDeviations(self):
        r"""GetUpdateFieldStandardDeviations(self) -> itkFixedArrayD2"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_GetUpdateFieldStandardDeviations(self)

    def StopRegistration(self):
        r"""StopRegistration(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_StopRegistration(self)

    def SetMaximumError(self, _arg):
        r"""
        SetMaximumError(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SetMaximumError(self, _arg)

    def GetMaximumError(self):
        r"""GetMaximumError(self) -> double"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_GetMaximumError(self)

    def SetMaximumKernelWidth(self, _arg):
        r"""
        SetMaximumKernelWidth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_SetMaximumKernelWidth(self, _arg)

    def GetMaximumKernelWidth(self):
        r"""GetMaximumKernelWidth(self) -> unsigned int"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_GetMaximumKernelWidth(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFilterPython.delete_itkPDEDeformableRegistrationFilterIUC2IUC2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFilterIUC2IUC2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPDEDeformableRegistrationFilterIUC2IUC2IVF22

        Create a new object of the class itkPDEDeformableRegistrationFilterIUC2IUC2IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPDEDeformableRegistrationFilterIUC2IUC2IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPDEDeformableRegistrationFilterIUC2IUC2IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPDEDeformableRegistrationFilterIUC2IUC2IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPDEDeformableRegistrationFilterIUC2IUC2IVF22 in _itkPDEDeformableRegistrationFilterPython:
_itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22_swigregister(itkPDEDeformableRegistrationFilterIUC2IUC2IVF22)

def itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_New():
    return itkPDEDeformableRegistrationFilterIUC3IUC3IVF33.New()

class itkPDEDeformableRegistrationFilterIUC3IUC3IVF33(itk.itkDenseFiniteDifferenceImageFilterPython.itkDenseFiniteDifferenceImageFilterIVF33IVF33):
    r"""Proxy of C++ itkPDEDeformableRegistrationFilterIUC3IUC3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_Pointer"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_Pointer"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_Clone(self)

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC3"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC3"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_GetMovingImage(self)

    def SetInitialDisplacementField(self, _arg):
        r"""
        SetInitialDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: itkImageVF33 const *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SetInitialDisplacementField(self, _arg)

    def GetInitialDisplacementField(self):
        r"""GetInitialDisplacementField(self) -> itkImageVF33"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_GetInitialDisplacementField(self)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF33"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_GetDisplacementField(self)

    def SetSmoothDisplacementField(self, _arg):
        r"""
        SetSmoothDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SetSmoothDisplacementField(self, _arg)

    def GetSmoothDisplacementField(self):
        r"""GetSmoothDisplacementField(self) -> bool"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_GetSmoothDisplacementField(self)

    def SmoothDisplacementFieldOn(self):
        r"""SmoothDisplacementFieldOn(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SmoothDisplacementFieldOn(self)

    def SmoothDisplacementFieldOff(self):
        r"""SmoothDisplacementFieldOff(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SmoothDisplacementFieldOff(self)

    def SetStandardDeviations(self, *args):
        r"""
        SetStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        SetStandardDeviations(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SetStandardDeviations(self, *args)

    def GetStandardDeviations(self):
        r"""GetStandardDeviations(self) -> itkFixedArrayD3"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_GetStandardDeviations(self)

    def SetSmoothUpdateField(self, _arg):
        r"""
        SetSmoothUpdateField(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SetSmoothUpdateField(self, _arg)

    def GetSmoothUpdateField(self):
        r"""GetSmoothUpdateField(self) -> bool"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_GetSmoothUpdateField(self)

    def SmoothUpdateFieldOn(self):
        r"""SmoothUpdateFieldOn(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SmoothUpdateFieldOn(self)

    def SmoothUpdateFieldOff(self):
        r"""SmoothUpdateFieldOff(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SmoothUpdateFieldOff(self)

    def SetUpdateFieldStandardDeviations(self, *args):
        r"""
        SetUpdateFieldStandardDeviations(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        SetUpdateFieldStandardDeviations(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SetUpdateFieldStandardDeviations(self, *args)

    def GetUpdateFieldStandardDeviations(self):
        r"""GetUpdateFieldStandardDeviations(self) -> itkFixedArrayD3"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_GetUpdateFieldStandardDeviations(self)

    def StopRegistration(self):
        r"""StopRegistration(self)"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_StopRegistration(self)

    def SetMaximumError(self, _arg):
        r"""
        SetMaximumError(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SetMaximumError(self, _arg)

    def GetMaximumError(self):
        r"""GetMaximumError(self) -> double"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_GetMaximumError(self)

    def SetMaximumKernelWidth(self, _arg):
        r"""
        SetMaximumKernelWidth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_SetMaximumKernelWidth(self, _arg)

    def GetMaximumKernelWidth(self):
        r"""GetMaximumKernelWidth(self) -> unsigned int"""
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_GetMaximumKernelWidth(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFilterPython.delete_itkPDEDeformableRegistrationFilterIUC3IUC3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFilterIUC3IUC3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPDEDeformableRegistrationFilterIUC3IUC3IVF33

        Create a new object of the class itkPDEDeformableRegistrationFilterIUC3IUC3IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPDEDeformableRegistrationFilterIUC3IUC3IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPDEDeformableRegistrationFilterIUC3IUC3IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPDEDeformableRegistrationFilterIUC3IUC3IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPDEDeformableRegistrationFilterIUC3IUC3IVF33 in _itkPDEDeformableRegistrationFilterPython:
_itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33_swigregister(itkPDEDeformableRegistrationFilterIUC3IUC3IVF33)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def pde_deformable_registration_filter(*args: itkt.ImageLike,  fixed_image: itkt.Image=..., moving_image: itkt.Image=..., initial_displacement_field: itkt.Image=..., smooth_displacement_field: bool=..., standard_deviations: Union[float, Sequence[float]]=..., smooth_update_field: bool=..., update_field_standard_deviations: Union[float, Sequence[float]]=..., maximum_error: float=..., maximum_kernel_width: int=..., difference_function=..., number_of_iterations: int=..., use_image_spacing: bool=..., maximum_rms_error: float=..., rms_change: float=..., manual_reinitialization: bool=..., is_initialized: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for PDEDeformableRegistrationFilter"""
    import itk

    kwarg_typehints = { 'fixed_image':fixed_image,'moving_image':moving_image,'initial_displacement_field':initial_displacement_field,'smooth_displacement_field':smooth_displacement_field,'standard_deviations':standard_deviations,'smooth_update_field':smooth_update_field,'update_field_standard_deviations':update_field_standard_deviations,'maximum_error':maximum_error,'maximum_kernel_width':maximum_kernel_width,'difference_function':difference_function,'number_of_iterations':number_of_iterations,'use_image_spacing':use_image_spacing,'maximum_rms_error':maximum_rms_error,'rms_change':rms_change,'manual_reinitialization':manual_reinitialization,'is_initialized':is_initialized }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.PDEDeformableRegistrationFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def pde_deformable_registration_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKPDEDeformableRegistration.PDEDeformableRegistrationFilter
    pde_deformable_registration_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    pde_deformable_registration_filter.__doc__ = filter_object.__doc__



